pub struct TypeLitExpr {
pub type_expr: TypeExpr,
pub span: Span,
}Expand description
A type literal expression (e.g., i32 used as a value).
This represents a type used as a value in expression context, typically
as an argument to a generic function with comptime parameters.
Fields
type_expr: TypeExprThe type being used as a value
span: SpanTrait Implementations
Sourceimpl Clone for TypeLitExpr
impl Clone for TypeLitExpr
Sourcefn clone(&self) -> TypeLitExpr
fn clone(&self) -> TypeLitExpr
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TypeLitExpr
impl Debug for TypeLitExpr
Sourceimpl PartialEq for TypeLitExpr
impl PartialEq for TypeLitExpr
impl Eq for TypeLitExpr
impl StructuralPartialEq for TypeLitExpr