pub enum Item {
Function(Function),
Struct(StructDecl),
Enum(EnumDecl),
DropFn(DropFn),
Const(ConstDecl),
Error(Span),
}Expand description
A top-level item in a source file.
Variants
Function(Function)
Struct(StructDecl)
Enum(EnumDecl)
DropFn(DropFn)
Const(ConstDecl)
Constant declaration (e.g., const math = @import("math");)
Error(Span)
Error node for recovered parse errors at item level. Used by error recovery to continue parsing after a syntax error.