TypeExpr

Enum TypeExpr 

pub enum TypeExpr {
    Named(Ident),
    Unit(Span),
    Never(Span),
    Array {
        element: Box<TypeExpr>,
        length: u64,
        span: Span,
    },
    AnonymousStruct {
        fields: Vec<AnonStructField>,
        methods: Vec<Method>,
        span: Span,
    },
    AnonymousEnum {
        variants: Vec<EnumVariant>,
        methods: Vec<Method>,
        span: Span,
    },
    PointerConst {
        pointee: Box<TypeExpr>,
        span: Span,
    },
    PointerMut {
        pointee: Box<TypeExpr>,
        span: Span,
    },
}
A type expression in the AST.

Variants



Named(Ident)

A simple named type (e.g., i32, bool, MyStruct)



Unit(Span)

Unit type: ()



Never(Span)

Never type: !



Array

Array type: [T; N] where T is the element type and N is the length

Fields

element: Box<TypeExpr>
length: u64
span: Span


AnonymousStruct

Anonymous struct type: struct { field: Type, fn method(…) { … }, … } Used in comptime type construction (e.g., fn Pair(comptime T: type) -> type { struct { first: T, second: T } }) Methods can be included inside the struct definition (Zig-style).

Fields

fields: Vec<AnonStructField>

Field declarations (name and type)

methods: Vec<Method>

Method definitions inside the anonymous struct

span: Span


AnonymousEnum

Anonymous enum type: enum { Variant, Variant(T), Variant { field: T }, fn method(…) { … }, … } Used in comptime type construction (e.g., fn Option(comptime T: type) -> type { enum { Some(T), None } }) Methods can be included inside the enum definition (Zig-style).

Fields

variants: Vec<EnumVariant>

Enum variants

methods: Vec<Method>

Method definitions inside the anonymous enum

span: Span


PointerConst

Raw pointer to immutable data: ptr const T

Fields

pointee: Box<TypeExpr>
span: Span


PointerMut

Raw pointer to mutable data: ptr mut T

Fields

pointee: Box<TypeExpr>
span: Span

Implementations

Source

impl TypeExpr

pub fn span(&self) -> Span

Get the span of this type expression.